==> muffin-0.5.tar.gz: muffin-0.5/src/muffin/Http.java <==
/* Http.java */

/* 
 * Copyright (C) 1997 Mark Boyns <boyns@sdsu.edu>
 *
 * This file is part of Muffin.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package muffin;

import java.net.URL;

/**
 * Read and write HTTP/1.0 transactions from a URL.
 * 
 * @see muffin.Proxy
 * @author Mark Boyns
 */
public class Http extends HttpRelay
{
    /**
     * @param url a URL
     */
    public Http (URL url) throws java.io.IOException
    {
	super (url.getHost (), url.getPort () == -1 ? 80 : url.getPort ());
    }

    /**
     * Write an HTTP/1.0 request.
     *
     * @param request a request
     */
    public void write (Request request) throws java.io.IOException
    {
	String oldStatusLine = request.statusLine;
	StringBuffer head = new StringBuffer ();
	head.append (request.getCommand ());
	head.append (" ");
	head.append (request.getPath ());
	head.append (" ");
	head.append (request.getProtocol ());
	request.statusLine = head.toString ();
	request.write (out);
	request.statusLine = oldStatusLine;
    }
}

==> muffin-0.6.tar.gz: muffin-0.6/src/muffin/Http.java <==
/* Http.java */

/* 
 * Copyright (C) 1996-98 Mark Boyns <boyns@sdsu.edu>
 *
 * This file is part of Muffin.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package muffin;

import java.net.URL;

/**
 * Read and write HTTP/1.0 transactions from a URL.
 * 
 * @see muffin.Proxy
 * @author Mark Boyns
 */
class Http extends HttpRelay
{
    /**
     * @param url a URL
     */
    Http (URL url) throws java.io.IOException
    {
	super (url.getHost (), url.getPort () == -1 ? 80 : url.getPort ());
    }

    /**
     * Write an HTTP/1.0 request.
     *
     * @param request a request
     */
    void write (Request request) throws java.io.IOException
    {
	String oldStatusLine = request.statusLine;
	StringBuffer head = new StringBuffer ();
	head.append (request.getCommand ());
	head.append (" ");
	head.append (request.getPath ());
	head.append (" ");
	head.append (request.getProtocol ());
	request.statusLine = head.toString ();
	request.write (out);
	request.statusLine = oldStatusLine;
    }
}
